==> toutdoux-1.2.4.tar.gz: ToutDoux-1.2.4/lib/toutdoux.h <==
/*****************************************************************************/
/* toutdoux.h : Types standards et fonctions standards
 * toutdoux.h : Usuals types and usuals functions
 *
 *
 * ToutDoux : Chtit gestionnaire de projet - A littl' project manage
 * Copyright (c) 2000 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@yahoo.com>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/

#include "commons.h"
#include "gtdk.h"
#include "icons.h"

#include "td_app.h"
#include "td_app_palette.h"
#include "td_app_editprop.h"
#include "td_app_menu.h"

#include "td_mod.h"
#include "td_mod_tree.h"
#include "td_mod_tree_menu.h"
#include "td_mod_tree_icon.h"
#include "td_mod_tree_prop.h"
#include "td_mod_tree_equal.h"
#include "td_mod_box.h"

#include "td_db_base.h"
#include "td_db_table.h"
#include "td_db_table_field.h"
#include "td_db_mod.h"
#include "td_db_mod_field.h"
#include "td_db_datatable.h"
#include "td_db_connect.h"

#include "td_field.h"
#include "td_field_dico.h"
#include "td_about.h"
#include "td_custom.h"
#include "td_custom_option.h"
#include "td_flower.h"

==> toutdoux-1.2.7.tar.gz: ToutDoux-1.2.7/lib/toutdoux.h <==
/*****************************************************************************/
/* toutdoux.h : Types standards et fonctions standards
 * toutdoux.h : Usuals types and usuals functions
 *
 *
 * ToutDoux : Chtit gestionnaire de projet - A littl' project manager
 * Copyright (c) 2000-2001 Philippe Roy
 * Auteur - Author : Philippe Roy <ph_roy@toutdoux.org>
 *
 *
 * Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier
 * sous les termes de la licence publique gnrale GNU telle qu'elle est publie par
 * la Free Software Foundation ; soit la version 2 de la licence, ou
 * (comme vous voulez) toute version ultrieure.
 *
 * Ce programme est distribu dans l'espoir qu'il sera utile,
 * mais SANS AUCUNE GARANTIE ; mme sans la garantie de
 * COMMERCIALIT ou d'ADQUATION A UN BUT PARTICULIER. Voir la
 * licence publique gnrale GNU pour plus de dtails.
 *
 * Vous devriez avoir reu une copie de la licence publique gnrale GNU
 * avec ce programme ; si ce n'est pas le cas, crivez  la Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
/*****************************************************************************/

#include "commons.h"
#include "gtdk.h"
#include "icons.h"
#include "cursors.h"
#include "database.h"

#include "td_app.h"
#include "td_app_palette.h"
#include "td_app_bench.h"
#include "td_app_etabliste.h"
#include "td_app_menu.h"
#include "td_app_process.h"

#include "td_mod.h"
#include "td_mod_bench.h"
#include "td_mod_etabliste.h"
#include "td_mod_menu.h"

#include "td_mod_tree.h"
#include "td_mod_tree_icon.h"
#include "td_mod_canvas.h"
#include "td_mod_canvas_symbol.h"
#include "td_mod_gantt.h"
#include "td_mod_box.h"
#include "td_mod_stree.h"

#include "td_db_base.h"
#include "td_db_table.h"
#include "td_db_mod.h"
#include "td_db_mod_table.h"
#include "td_db_mod_menu.h"
#include "td_db_datatable.h"
#include "td_db_connect.h"

#include "td_field.h"
#include "td_rule.h"
#include "td_function.h"
#include "td_dico.h"
#include "td_about.h"
#include "td_flower.h"

#include "td_timeruler.h"
#include "td_panwindow.h"
